@@ -6,6 +6,7 @@ import infima_client.core.api.cohort_v1.cohort_v1_check_exists as _check_exists
 import infima_client.core.api.cohort_v1.cohort_v1_find as _find
 import infima_client.core.api.cohort_v1.cohort_v1_get_actual_prepayments as _get_actual_prepayments
 import infima_client.core.api.cohort_v1.cohort_v1_get_cohort_summary as _get_cohort_summary
+import infima_client.core.api.cohort_v1.cohort_v1_get_covered_cohorts as _get_covered_cohorts
 import infima_client.core.api.cohort_v1.cohort_v1_get_member_lists as _get_member_lists
 import infima_client.core.api.cohort_v1.cohort_v1_get_member_pools as _get_member_pools
 import infima_client.core.api.cohort_v1.cohort_v1_get_pool_memberships as _get_pool_memberships
@@ -23,6 +24,7 @@ from infima_client.core.models import (
     CohortV1GetActualPrepaymentsResponse,
     CohortV1GetCohortSummaryRequest,
     CohortV1GetCohortSummaryResponse,
+    CohortV1GetCoveredCohortsResponse,
     CohortV1GetMemberListsRequest,
     CohortV1GetMemberListsResponse,
     CohortV1GetMemberPoolsRequest,
@@ -117,6 +119,14 @@ class CohortV1:
             raise ValueError("no data returned from the service")
         return response
 
+    def get_covered_cohorts(self) -> CohortV1GetCoveredCohortsResponse:
+        response = _get_covered_cohorts.sync(client=self.client)
+        if isinstance(response, GoogleRpcStatus):
+            raise ValueError(response.message)
+        if response is None:
+            raise ValueError("no data returned from the service")
+        return response
+
     def get_member_lists(
         self, *, cohorts: List[str], factor_date: Optional[CoreFactorDate] = None
     ) -> CohortV1GetMemberListsResponse:
