@@ -22,7 +22,7 @@ T = TypeVar("T", bound="PoolV1GetSummaryRequest")
 class PoolV1GetSummaryRequest:
     """
     Attributes:
-        cusips (List[str]): Pool CUSIPs to fetch summaries. Example: 31417EUD1.
+        cusips (List[str]): Pool CUSIPs to fetch summaries. Example: ['31417EUD1'].
     """
 
     cusips: List[str]
