@@ -24,7 +24,7 @@ T = TypeVar("T", bound="PredictionV1GetRequest")
 class PredictionV1GetRequest:
     """
     Attributes:
-        symbols (List[str]): Pool CUSIPs or cohort names to fetch individual prepayment predictions. Example: 31417EUD1.
+        symbols (List[str]): Pool CUSIPs or cohort names to fetch individual prepayment predictions.
         as_of (Union[Unset, CoreDate]):
     """
 
